@@ -9,7 +9,7 @@ use File::stat;
 use File::Temp;
 use File::Which;
 
-our $VERSION = '0.22';
+our $VERSION = '0.30';
 
 
 =head1 NAME
@@ -120,6 +120,7 @@ hook 'after' => sub {
 };
 
 get '/nytprof' => sub {
+    require Devel::NYTProf::Data;
     opendir my $dirh, $setting->{profdir}
         or die "Unable to open profiles dir $setting->{profdir} - $!";
     my @files = grep { /^nytprof\.out/ } readdir $dirh;
@@ -142,7 +143,13 @@ produced by <tt>Devel::NYTProf</tt>.</p>
 <ul>
 LISTSTART
 
-    for my $file (@files) {
+    for my $file (
+        sort {
+            (stat Dancer::FileUtils::path($setting->{profdir},$b))->ctime
+            <=>
+            (stat Dancer::FileUtils::path($setting->{profdir},$a))->ctime
+        } @files
+    ) {
         my $fullfilepath = Dancer::FileUtils::path($setting->{profdir}, $file);
         my $label = $file;
         $label =~ s{nytprof\.out\.}{};
@@ -150,8 +157,23 @@ LISTSTART
         $label =~ s{\.(\d+)$}{};
         my $pid = $1;  # refactor this crap
         my $created = scalar localtime( (stat $fullfilepath)->ctime );
+
+        # read the profile to find out the duration of the profiled request.
+        # Done in an eval to catch errors (e.g. if a profile run died mid-way,
+        # the data will be incomplete
+        my ($profile,$duration);
+        eval {
+            $profile = Devel::NYTProf::Data->new({ filename => $fullfilepath});
+        };
+        if ($profile) {
+            $duration = sprintf '%.4f secs', 
+                $profile->attributes->{profiler_duration};
+        } else {
+            $duration = '??? seconds - corrupt profile data?';
+        }
+
         $html .= qq{<li><a href="/nytprof/$file">$label</a>}
-               . qq{ (PID $pid, $created)</li>};
+               . qq{ (PID $pid, $created, $duration)</li>};
     }
 
     $html .= <<LISTEND;
@@ -242,6 +264,10 @@ Stefan Hornburg (racke)
 
 Neil Hooey (nhooey)
 
+J. Bobby Lopez (jbobbylopez)
+
+leejo
+
 
 =head1 BUGS
 
@@ -267,7 +293,7 @@ L<Plack::Middleware::Debug::Profiler::NYTProf>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 David Precious.
+Copyright 2011-12 David Precious.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
